#include "nacc.h"
#include "setupmenu.h"


///////////////////////////////////////////////////////////////////////////////


NACCConfig config;

const char* PluginCC::VERSION        = "0.0.2";
const char* PluginCC::DESCRIPTION    = "Closed Captioning for NTSC TV";
const char* PluginCC::MAINMENUENTRY  = "Closed Captioning";
  
  
///////////////////////////////////////////////////////////////////////////////


PluginCC::PluginCC(void)
{
  // Initialize any member variables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
  
  config.CCType = 0; // CC1
  config.Active = true;
  config.OverrideColors = false;
  config.BgClr = 0; // Black
  config.FgClr = 1; // White
  config.StartType = S_AUTOMATIC; // Automatic
  config.HideMenuEntry = true;
  
  manager = NULL;
  
  setLogType(L_MSG | L_ERR);// | L_TXT);
}


//-----------------------------------------------------------------------------

PluginCC::~PluginCC()
{
  // Clean up after yourself!  
  delete manager;
}


//-----------------------------------------------------------------------------

const char* PluginCC::MainMenuEntry(void)
{
  if (config.StartType != S_AUTOMATIC && !config.HideMenuEntry && config.Active)
    return MAINMENUENTRY;
  else
    return NULL;  
}


//-----------------------------------------------------------------------------

const char* PluginCC::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return NULL;
}


//-----------------------------------------------------------------------------

bool PluginCC::Start()
{
  // Start any background activities the plugin shall perform.
  // RegisterI18n(Phrases);
  if (config.Active) {
    dprint(L_MSG, "Starting Manager");
    manager = new CCManager(); 
  }   
  
  return true;
}


//-----------------------------------------------------------------------------

cOsdObject* PluginCC::MainMenuAction(void)
{
  if (config.Active && config.StartType != S_AUTOMATIC) 
  {
    if (!manager) {
      dprint(L_ERR, "MainMenuAction: manager is NULL");
      return NULL;
    }
    
    if (manager->CCActive())
      manager->Stop();
    else  
      manager->StartCC();
  }
  
  return NULL;
}


//-----------------------------------------------------------------------------

void  PluginCC::StartFromSetup(void)
{
  if (config.Active) 
  {
    if (!manager) {
      dprint(L_MSG, "Starting Manager");
      manager = new CCManager();
    }
      
    manager->ChannelSwitch(cDevice::ActualDevice(), 
                           cDevice::PrimaryDevice()->CurrentChannel() );
    // Need to retune channel to activate
    //Channels.SwitchTo( cDevice::PrimaryDevice()->CurrentChannel() );  
  }  
  else
  {
    dprint(L_MSG, "Stopping Manager");
    delete manager;
    manager = NULL;
  }  
}


//-----------------------------------------------------------------------------

cMenuSetupPage* PluginCC::SetupMenu(void)
{
  return new CCSetupMenu(this, manager);
}


//-----------------------------------------------------------------------------

bool PluginCC::SetupParse(const char *Name, const char *Value)
{   
  if      (!strcasecmp(Name, "CCType"))  config.CCType = atoi(Value);
  else if (!strcasecmp(Name, "Active"))  config.Active = atoi(Value);
  else if (!strcasecmp(Name, "BgClr"))  config.BgClr = atoi(Value);
  else if (!strcasecmp(Name, "FgClr"))  config.FgClr = atoi(Value);
  else if (!strcasecmp(Name, "OverrideColors"))  config.OverrideColors = atoi(Value);
  else if (!strcasecmp(Name, "StartType"))  config.StartType = atoi(Value);
  else if (!strcasecmp(Name, "HideMenuEntry"))  config.HideMenuEntry = atoi(Value);
  else return false;
  
  
  return true;
}


///////////////////////////////////////////////////////////////////////////////


VDRPLUGINCREATOR(PluginCC); // Don't touch this!


///////////////////////////////////////////////////////////////////////////////

