#include "receiver.h"


///////////////////////////////////////////////////////////////////////////////


#if VDRVERSNUM >= 10500
CCReceiver::CCReceiver(CCParser* p, tChannelID ChannelID, int Vpid, int Apid[], int Dpid[])
:cReceiver(ChannelID, -1, Vpid, Apid, Dpid, NULL)
#else
CCReceiver::CCReceiver(CCParser* p, int Ca, int Vpid, int Apid[], int Dpid[])
:cReceiver(Ca, -1, Vpid, Apid, Dpid, NULL)
#endif
{
  parser = p;
  attachedDevice = NULL;
  m_lastPacketSize = -1;
}
 
CCReceiver::~CCReceiver(void)
{
  Detach();
  dprint(L_DBG, "Receiver: Destructor.");
}

//-----------------------------------------------------------------------------

void CCReceiver::Attach(cDevice* device)
{
  if (!attachedDevice) 
  {
    attachedDevice = device;
    if (attachedDevice) 
    {
      attachedDevice->AttachReceiver(this);
      dprint(L_DBG, "Receiver: Attached.");
    }
  }
}

//-----------------------------------------------------------------------------

void CCReceiver::Detach(void)
{
  if (attachedDevice) 
  {
    attachedDevice->Detach(this);
    attachedDevice = NULL;
    dprint(L_DBG, "Receiver: Detached.");
  }
}


//-----------------------------------------------------------------------------

#define TS_SIZE       188
#define PAY_START     0x40
#define ADAPT_FIELD   0x20
#define PAYLOAD       0x10
#define PTS_DTS_FLAGS 0xC0


void CCReceiver::Receive(uchar *Data, int Length)
{
  if(m_lastPacketSize != Length)
  {
    m_lastPacketSize = Length;
  }
  if (Length == TS_SIZE) 
  { 
    /* the following originates from libdvbmpeg */
    if (!(Data[3] & PAYLOAD)) {
      return;
    } 
    
    uint8_t off = 0;
    if (Data[3] & ADAPT_FIELD) {
      off = Data[4] + 1;
    }
    if (Data[1] & PAY_START) {
      uint8_t *sb = Data + 4 + off;
      if (sb[7] & PTS_DTS_FLAGS) {
        uint8_t *pay = sb + sb[8] + 9; 
        int l = TS_SIZE - 13 - off - sb[8];
        if(l>0) {
          parser->Put(pay, l);           
        }
      }
    }
  }  
}


///////////////////////////////////////////////////////////////////////////////

